%let name=us_jobs_2017;
filename odsout '.';

/*
Creating my own version of this graph:
https://flowingdata.com/2018/07/23/most-common-jobs-by-state/

Using data from:
https://www.bls.gov/oes/tables.htm
*/

libname robsdata '.';

%let year=2017;

PROC IMPORT OUT=all_data DATAFILE="D:\Public\BLS\oes\state_&year._dl.xlsx" DBMS=xlsx REPLACE;
range="$A&first.:G0";
GETNAMES=YES;
RUN;

data all_data (keep = year statecode statename occ_title occ_group employment); 
 set all_data (rename=(st=statecode state=statename));
format employment comma10.0;
employment=.; employment=tot_emp;
if employment^=. then output;
run;

data detailed_data; set all_data (where=(occ_group='detailed'));
run;

proc sort data=detailed_data out=detailed_data;
by statecode descending employment;
run;

/* Assign a numeric rank to each occupation, by state */
data detailed_data; set detailed_data;
by statecode;
if first.statecode then rank=1;
else rank+1;
run;

data top5_detailed; set detailed_data (where=(rank<=5));
run;

/* For each state, create a single html mouse-over with all the top 5 for that state */
data top5_html (keep = statecode my_html); set top5_detailed;
by statecode;
length my_html $1000;
retain my_html;
if first.statecode then do;
 my_html='title="'||trim(left(statename))||"'s top 5 occupations in &year";
 end;
my_html=trim(left(my_html))||'0d'x||
   trim(left(rank))||': '||trim(left(occ_title))||' ('||trim(left(put(employment,comma8.0)))||')';
if last.statecode then do;
 my_html=trim(left(my_html))||'"';
 output;
 end;
run;

/* merge in the HTML mouse-over text for the top 5 */
proc sql noprint;
create table top5_detailed as 
select unique top5_detailed.*, top5_html.my_html
from top5_detailed left join top5_html
on top5_detailed.statecode=top5_html.statecode;
quit; run;

/* Eliminate Guam, and a few other territories */
proc sql noprint; 
create table top5_detailed as
select * 
from top5_detailed
where statecode in (select unique statecode from mapsgfk.us);
quit; run;

/*
Count how many states have each job title in their top 5
*/
proc sql noprint;
create table top5_detailed as
select unique *, count(*) as title_count
from top5_detailed
group by occ_title;
quit; run;

proc sort data=top5_detailed out=top5_detailed;
by descending title_count occ_title;
run;

/*
I annotate the titles, so I can split some of them into two lines 
*/
proc sql noprint;
create table anno_titles as
select unique occ_title, title_count
from top5_detailed
order by title_count desc, occ_title;
quit; run;

data anno_titles; set anno_titles;
length line1 line2 $100;
line1=occ_title;
line2=' ';
if occ_title='Combined Food Preparation and Serving Workers, Including Fast Food' then do;
 line1='Combined Food Preparation and Serving';
 line2='Workers, Including Fast Food';
 end;
if occ_title='Laborers and Freight, Stock, and Material Movers, Hand' then do;
 line1='Laborers and Freight, Stock,';
 line2='and Material Movers, Hand';
 end;
if occ_title='Secretaries and Administrative Assistants, Except Legal, Medical, and Executive' then do;
 line1='Secretaries and Administrative Assistants,';
 line2='Except Legal, Medical, and Executive';
 end;
if occ_title='Assemblers and Fabricators, All Other, Including Team Assemblers' then do;
 line1='Assemblers and Fabricators, All Other,';
 line2='Including Team Assemblers';
 end;
if occ_title='Janitors and Cleaners, Except Maids and Housekeeping Cleaners' then do;
 line1='Janitors and Cleaners, Except Maids';
 line2='and Housekeeping Cleaners';
 end;
if occ_title='' then do;
 line1='';
 line2='';
 end;
xsys='3'; ysys='3'; hsys='3'; when='a';
function='label'; size=5.5; style='albany amt/bold'; position='5'; 
x=50;
y=95.5; text=line1; output;
y=89.0; text=line2; output;
run;

/*
Get the US map, and make DC bigger, and move it out into the ocean.
*/
data my_map; set mapsgfk.us;
if statecode='DC' then do;
 x=x*4;
 y=y*4;
 x=x-.70;
 y=y-.17;
 end;
run;

/* create an annotated 'shadow' behind the map */
data anno_map_shadow; set my_map;
length function $8 style $35;
by state segment notsorted;
xsys='2'; ysys='2'; hsys='3'; when='b';
style='solid'; color='gray22';
if first.segment then function='poly';
else function='polycont';
run;
data anno_map_shadow; set anno_map_shadow;
x=x+.0009;
y=y-.0009;
run;


goptions device=png;
goptions border;
 
/*
ODS LISTING CLOSE;
ODS HTML path=odsout body="&name..htm" 
 (title="Most Common Jobs (&year)") 
 style=htmlblue;
*/

ODS LISTING CLOSE;

%let panelcolumns=2;
ods tagsets.htmlpanel path=odsout file="&name..htm" 
 (title="Most Common Jobs (&year)") 
 style=htmlblue;



goptions gunit=pct ftitle='albany amt/bold' ftext='albany amt' htitle=6 htext=3;
goptions ctext=gray33;

goptions xpixels=804 ypixels=75;
title1 h=22pt f='albany amt/bold' ls=8.0 "5 Most Common Jobs in Each State (2017)";
title2 h=12pt
 link='https://www.bls.gov/oes/tables.htm'
 ls=1.8 c=gray77 "Data source: Bureau of Labor Statistics, Occupational Employment Statistics";
proc gslide des='' name="&name";
run;


ods tagsets.htmlpanel event = panel(start);

pattern1 v=s c=cx1fe2ae; /* light green */

options nobyline;
/*
title1 "#byval(occ_title)";
*/
title1 h=8pct ' ';

goptions xpixels=400 ypixels=300;
proc gmap data=top5_detailed map=my_map all;
/*
by occ_title notsorted;
*/
by descending title_count occ_title;
id statecode;
choro occ_title / nolegend
 coutline=grayf5 cempty=graycc
 cdefault=grayf2
 anno=anno_titles
 html=my_html
 des='' name="&name._";
run;

ods tagsets.htmlpanel event = panel(finish);

/*
proc print data=top5_detailed; run;
proc print data=anno_titles; run;
*/

quit;
ods _all_ close;

/*
quit;
ODS HTML CLOSE;
ODS LISTING;
*/
